@@ -22,6 +22,8 @@ describe 'panko::wsgi::apache' do
         :wsgi_script_dir     => platform_params[:wsgi_script_path],
         :wsgi_script_file    => 'app',
         :wsgi_script_source  => platform_params[:wsgi_script_source],
+        :access_log_file     => false,
+        :access_log_format   => false,
       )}
     end
 
@@ -37,6 +39,9 @@ describe 'panko::wsgi::apache' do
           :custom_wsgi_process_options => {
             'python_path' => '/my/python/admin/path',
           },
+          :access_log_file           => '/var/log/httpd/access_log',
+          :access_log_format         => 'some format',
+          :error_log_file            => '/var/log/httpd/error_log'
         }
       end
       it { is_expected.to contain_class('panko::params') }
@@ -62,6 +67,9 @@ describe 'panko::wsgi::apache' do
         :custom_wsgi_process_options => {
           'python_path'  => '/my/python/admin/path',
         },
+        :access_log_file           => '/var/log/httpd/access_log',
+        :access_log_format         => 'some format',
+        :error_log_file            => '/var/log/httpd/error_log'
       )}
     end
   end
